@@ -7,7 +7,10 @@ A collection of handy utilities to support django operations.
 """
 
 __title__ = 'django-handyhelpers'
-__version__ = '0.0.2'
+__version__ = '0.0.16'
 __author__ = 'David Slusser'
+__email__ = 'dbslusser@gmail.com'
 __license__ = 'GPL-3.0'
-__copyright__ = 'Copyright 2018 David Slusser'
+__copyright__ = 'Copyright 2020 David Slusser'
+
+default_app_config = 'handyhelpers.apps.HandyHelpersConfig'
